@@ -3,11 +3,10 @@ plot.fmres <- function (x, type = c("image", "fts", "contour", "filled.contour",
 {
     type <- match.arg(type)
     switch(type, 
-      image = image(x$x, x$y, x$z, ylab = ylab, xlab = xlab, ...), 
-      fts = plot(fts(x$y, t(x$z), start = x$x[1], xname = xlab, yname = ylab), ...), 
+      image = image(x$x, x$y, x$z, ylab = ylab, xlab = xlab, col = diverge_hcl(25, c=360, l=c(10,90)), ...), 
+      fts = plot(fts(x$y, t(x$z), start = x$x[1], xname = xlab, yname = "Residuals"), ...), 
       contour = contour(x$x, x$y, x$z, ylab = ylab, xlab = xlab, ...), 
       filled.contour = filled.contour(x$x, x$y, x$z, ylab = ylab, xlab = xlab, ...), 
       persp = persp(x$x, x$y, x$z, ylab = ylab, xlab = xlab, zlab = zlab, ...)
     )
-    box()
 }
